=============
hpc_scheduler
=============


.. image:: https://img.shields.io/pypi/v/scheduler.svg
        :target: https://pypi.python.org/pypi/scheduler

.. image:: https://img.shields.io/travis/larsbuntemeyer/scheduler.svg
        :target: https://travis-ci.com/larsbuntemeyer/scheduler

.. image:: https://readthedocs.org/projects/hpc-scheduler/badge/?version=latest
        :target: https://hpc-scheduler.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Python code to interact with an HPC scheduler.


* Free software: MIT license
* Documentation: https://hpc-scheduler.readthedocs.io.


Features
--------

* create jobscripts from templates with python (only SLURM right now)
* interact with the job scheduler (submit and check jobs, check accounting, group jobs)

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
